Liquid
======


Liquid properties such as heat capacity can be calculated using the method available in the :code:`Liquid` class. The method is based on a correlation and is named accordingly; for example, the :code:`cp_yaws()` method uses Yaws' coefficients to calculate the heat capacity for a range of temperatures.

.. autoclass:: chemics.Liquid
   :members:
